@@ -1,5 +1,7 @@
 #!/usr/bin/perl -w
 
+# $Id: smbldap_tools.pm 26 2010-11-15 14:28:01Z mm1 $
+
 #  This code was developped by Jerome Tournier (jtournier@gmail.com) and
 #  contributors (their names can be found in the CONTRIBUTORS file).
 
@@ -92,6 +94,7 @@ use vars qw(%config $ldap);
   get_user_dn2
   connect_ldap_master
   connect_ldap_slave
+  group_name_by_type
   group_type_by_name
   subst_configvar
   read_config
@@ -825,9 +828,9 @@ sub read_user {
         $lines .= "dn: " . $entry->dn . "\n";
         foreach my $attr ( $entry->attributes ) {
             my @vals = $entry->get_value($attr);
-            foreach my $val (@vals) {
-                $val = "**UNPRINTABLE**" if ( $val =~ /[^[:print:]]/ );
-            }
+#            foreach my $val (@vals) {
+#                $val = "**UNPRINTABLE**" if ( $val =~ /[^[:print:]]/ );
+#            }
             $lines .= $attr . ": " . join( ',', @vals ) . "\n";
         }
     }
@@ -1099,6 +1102,16 @@ EOF
     return $rc;
 }
 
+sub group_name_by_type {
+    my $groupmap = shift;
+    my %type_name  = (
+	2 => 'domain',
+	4 => 'local',
+	5 => 'builtin'
+    );
+    return $type_name{$groupmap};
+}
+
 sub group_type_by_name {
     my $type_name = shift;
     my %groupmap  = (
@@ -1209,22 +1222,33 @@ sub get_next_id($$) {
 }
 
 sub utf8Encode {
-    my $arg = shift;
+    my $charset = shift;
+    my $string = shift;
 
-    return to_utf8(
-        -string  => $arg,
-        -charset => 'ISO-8859-1',
-    );
+    if ($charset eq "UTF-8") {
+	return $string;
+    }
+    else {
+	return to_utf8(
+	    -string  => $string,
+	    -charset => $charset,
+	);
+    }
 }
 
 sub utf8Decode {
-    my $arg = shift;
+    my $charset = shift;
+    my $string = shift;
 
-    return from_utf8(
-        -string  => $arg,
-        -charset => 'ISO-8859-1',
-    );
+    if ($charset eq "UTF-8") {
+	return $string;
+    }
+    else {
+	return from_utf8(
+	    -string  => $string,
+	    -charset => $charset,
+	);
+    }
 }
 
 1;
-
